from .model import WeightedMetapath2VecModel


__all__ = ['WeightedMetapath2VecModel']

# manual versioning is DEPRECATED, use importlib.metadata to read the package version
# __version__ = '0.1.3'
